from typing import Tuple, Union

from PIL import Image


class Canvas:
    def __init__(
        self,
        size: Tuple[float, float],
        color: Union[Tuple[int, int, int], str, int] = None,
    ) -> None:
        self.size = size
        self.color = color

        self.image = Image.new("RGBA", size, color=color)



from collections import namedtuple
from .canvas import Canvas
from .editor import Editor
from .font import Font
from .text import Text
from .utils import run_in_executor, load_image, load_image_async

__version__ = "0.0.6"
VersionInfo = namedtuple("VersionInfo", "major minor macro release")

version_info = VersionInfo(0, 0, 5, "stable")
